#read_xls_and_plot
# Python script which reads an Excel file containing x vs y data
# and plots this, creating a print ready PNG file.
#
# Adapted from https://blogs.harvard.edu/rprasad/2014/06/16/reading-excel-with-python-xlrd/
# TeX Mathematical annotations reference: https://matplotlib.org/users/mathtext.html

# LAST UPDATED by Andy French December 2017

#Import Python numeric, plotting and xls reading libraries
import numpy as Npy
import matplotlib as mpl
mpl.use('Agg')
import matplotlib.pyplot as plt
import xlrd

#Hard coded filename
filename = "Excel xy.xls"

#Greeting message
print("\n Python Excel file reading and plotting demo ")
print(" By Dr Andrew French. December 2017\n")
print(" Reading file: " + filename + " and plotting x,y data.")

#Open the workbook
xl_workbook = xlrd.open_workbook(filename)

#List sheet names
sheet_names = xl_workbook.sheet_names()
print(" Workbook sheet name is: " + sheet_names[0])

#Extract the 'zeroth' Excel sheet
X = xl_workbook.sheet_by_name(sheet_names[0])

#Determine number of rows and columns
num_rows = X.nrows
num_cols = X.ncols

#Initialize data vectors x,y. Note headers on first three rows in file
x = Npy.zeros((1,num_rows-3))
x = x[0]
y = Npy.zeros((1,num_rows-3))
y = y[0]
yrand = Npy.zeros((1,num_rows-3))
yrand = yrand[0]

#Step through Excel sheet and populate data vectors
for row in range(3,num_rows):
    i = row - 3
    x[i] = float( X.cell(row,0).value )
    y[i] = float( X.cell(row,1).value )
    yrand[i] = float( X.cell(row,2).value )

#Create figure and axis
fig = plt.figure(figsize=(10, 8))

#Plot y vs x
fsize = 18
plt.plot( x,y,'-',label = "$y = 3\sqrt{x}$" , color = [1,0,0] )
plt.plot( x,yrand,'+',label = "$y = 3\sqrt{x}$ + noise" , color = [1,0,0] )
plt.xlabel( "$\mathit{x}$", size=fsize*1.2 );
plt.ylabel( "$\mathit{y}$", size=fsize*1.2 );
plt.xticks( fontsize = fsize )
plt.yticks( fontsize = fsize )
plt.title( "$y = 3\sqrt{x}$ + noise", size=fsize*1.2 )
plt.legend( fontsize = fsize*1.2,loc = "lower right", numpoints=1 )
plt.grid(True)
plt.xlim( 0, Npy.nanmax(x) )

#Export PNG file
fig.savefig('Excel xy.png', dpi=300)

#Wait for user input to close terminal window
input("\n Press any key to continue ...")

#End of code
